# Streamlit Image Crop

A [Streamlit](https://www.streamlit.io/) component based on [React Image Crop](https://github.com/DominicTobias/react-image-crop).

![Screenshot](https://raw.githubusercontent.com/mitsuse/streamlit-image-crop/master/screenshot.png)

## Installation

```
pip install streamlit-image-crop
```

## Example

Please see [example.py](example.py).

## License

Streamlit Image Crop is licensed under the ISC license.
Please read [LICENSE](LICENSE) for the detail.
